import Vue from "vue";
import VueRouter from "vue-router";
import demoRoutes from "./example";
// import testRoutes from "./test";

import Login from "../views/Login.vue"
import NotFound from "../views/404"
import Layout from '@comp/Layout'

Vue.use(VueRouter);

let routes = [
  {
    path: '/',
    component: Layout,
    redirect: '/regionalPlate',
    name: 'home',
    meta: { title: '首页' },
    hidden: true
  },
  {
    path: '/regionalPlate',
    hidden: false,
    meta: { title: '区域板块楼盘', icon: 'el-icon-discover' },
    component: Layout,
    children: [
      {
        path: '/regionalPlate',
        name: 'regionalPlate',
        hidden: false,
        meta: { title: '区域板块楼盘' },
        component: () => import('@/views/RegionalPlate/index.vue'),
      }
    ]
  },
  {
    path: '/plateSupplyData',
    hidden: false,
    meta: { title: '产品供求数据', icon: 'el-icon-search' },
    component: Layout,
    children: [
      {
        path: '/plateSupplyData',
        name: 'plateSupplyData',
        meta: { title: '产品供求数据' },
        hidden: false,
        component: () => import('@/views/plateSupplyData/index.vue'),
      }
    ]
  },
  {
    path: '/ProductAnalysis',
    hidden: false,
    meta: { title: '产品数据分析', icon: 'el-icon-pie-chart' },
    component: Layout,
    children: [
      {
        path: '/ProductAnalysis',
        name: 'ProductAnalysis',
        hidden: false,
        meta: { title: '产品数据分析' },
        component: () => import('@/views/ProductAnalysis/index.vue'),
      }
    ]
  },
  {
    path: '/detail',
    hidden: true,
    meta: { title: '楼盘详情' },
    component: Layout,
    children: [
      {
        path: '/propertiesDetail',
        name: 'propertiesDetail',
        hidden: false,
        meta: { title: '楼盘详情' },
        component: () => import('@/views/propertiesDetail/index.vue'),
      }
    ]
  },
  {
    path: '/tenioStore',
    hidden: false,
    name: 'tenioStore',
    meta: { title: '天友户型库', icon: 'el-icon-s-platform', outerNet: true },
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'tenioStore',
        hidden: false,
        meta: { title: '天友户型库', icon: 'el-icon-s-platform', outerNet: true },
        component: () => import('@/views/tenioStore/index.vue'),
      }
    ]
  },
  {
    path: "/login",
    name: "login",
    component: Login,
    hidden: true
  },
  { path: '/404', component: NotFound, hidden: true },
  { path: '*', redirect: '/404', hidden: true }
]

const originalPush = VueRouter.prototype.push
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
}

if (process.env.NODE_ENV !== 'production') {
  routes = routes.concat(demoRoutes)
  // routes = routes.concat(testRoutes)
}

const router = new VueRouter({
  routes
})

export default router
